#ifndef __MyChannel_h__
#define __MyChannel_h__

#include <TClonesArray.h>

class MyEvent;
class MyPuls;

class MyChannel : public TObject
{
public:
	MyChannel():
	  fullscale(0),
	  offset(0),
	  gain(0),
	  baseline(0),
	  noise(0),
	  stsi(0),
	  bs(0),
	  chNbr(0),
	  parentEvent(0),
	  nbrPulses(0),
	  pulses("MyPuls",100),
	  rawdata(0),
	  rawLength(0),
	  rawLengthBuffer(0)	{}

	MyChannel(MyEvent* pe):
	  fullscale(0),
	  offset(0),
	  gain(0),
	  baseline(0),
	  noise(0),
	  stsi(0),
	  bs(0),
	  chNbr(0),
	  parentEvent(pe),
	  nbrPulses(0),
	  pulses("MyPuls",100),
	  rawdata(0),
	  rawLength(0),
	  rawLengthBuffer(0)	{}
	
	~MyChannel()			{}

protected:
	MyChannel& operator=(const MyChannel& in)	{return *this;}
	MyChannel(const MyChannel& in)				{}

public:
	void clear();
	MyPuls*addPuls();
	MyPuls*getPuls(long idx)const				{return reinterpret_cast<MyPuls*>(pulses[idx]);}
	short  getNbrPulses() const					{return nbrPulses;}
	void   copyRawData(char * in, size_t length);

	short  getBaseline() const					{return baseline;}
	void   setBaseline(short in)				{baseline = in;}
	short  getNoise() const						{return noise;}
	void   setNoise(short in)					{noise = in;}
	short  getFullScale()const 					{return fullscale;}
	void   setFullScale(short in)				{fullscale=in;}
	short  getOffset() const					{return offset;}
	void   setOffset(short in)					{offset=in;}
	double getVertGain()const 					{return gain;}
	void   setVertGain(double in)				{gain=in;}
	long   getStepSize() const					{return stsi;}
	void   setStepSize(long in)					{stsi = in;}
	long   getBackSize() const					{return bs;}
	void   setBackSize(long in)					{bs = in;}
	long   getChannelNbr() const				{return chNbr;}
	void   setChannelNbr(long in)				{chNbr = in;}
	void  *getRawData() const					{return rawdata;}
	void   setRawDataLength(size_t in)			{rawLength = in;}
	size_t getRawDataLength() const				{return rawLength;}

	MyEvent *getParentEvent()					{return parentEvent;}


private:
	//these variables could go into a header//	
	short fullscale;					//the fullscale for this channel (in mV)
	short offset;						//the offset for this channel (in mV)
	double gain;						//the conversion factor from adc bytes to mV (adc bytes * gain = mV)
	short baseline;						//the baseline for this channel (in adc bytes)
	short noise;						//the noiselevel for this channel (in adc bytes)
	long stsi;							//the stepsize for this channel
	long bs;							//the backsize for this channel
	long chNbr;							//the channel number of this channel

	//these don't need to be recorded//
	char *rawdata;						//!pointer to the raw data
	size_t rawLengthBuffer;				//!length of the raw databuffer
	size_t rawLength;					//!length of the raw data in data type units

	//these need to be written into the tree for each event//
	MyEvent *parentEvent;				//pointer to the event that this channel belong to
	size_t nbrPulses;					//nbr of Pulses this channel currently has
	TClonesArray pulses;				//Container storing the pulses
	
	ClassDef(MyChannel,1)	//One Channel
};
#endif
