#include <TStyle.h>
#include <TH1.h>
#include <iostream>
#include <TPad.h>
#include <TCanvas.h>
#include <TGClient.h>



#include "MyEventViewer.h"

#include "../MyEvent/MyEvent.h"
#include "../MyChannel/MyChannel.h"
#include "../MyPuls/MyPuls.h"


TCanvas* Canv(int hor, int ver);
//___________________________________________________________________________________________________________________________________________________________
MyEventViewer::~MyEventViewer()
{
	//delete histograms//
	for (int i=0;i<nbrOfHitsCreated;++i)
		delete hists[i];
	delete [] hists;

	//delete Canvas
	delete c;
}

//___________________________________________________________________________________________________________________________________________________________
void MyEventViewer::init(MyEvent* ev)
{
	//set the global style for marker//
	gStyle->SetMarkerStyle(21);
	gStyle->SetMarkerSize(0.5);

	//how many Channels do we have//
	long nbrChannels = ev->getNbrOfChannels();

	//create a Canvas with enough pads for each Channel//
	c = Canv(4,nbrChannels/4);
	
	//create an array of Histograms. Each Histogram represents one Channel//
	hists = new TH1D*[nbrChannels]; 
	nbrOfHitsCreated = nbrChannels;	//remember how many have been created

	//go through all channels//
	for (size_t chan=0; chan < nbrChannels; ++chan)
	{
		//create Channel Histograms//
		TString HistName(Form("%s_Channel%d",name.Data(),chan+1));
		TString HistTitle(Form("Channel %i",chan+1));
		hists[chan] = new TH1D(HistName.Data(),HistTitle.Data(),ev->getNbrSamples(),-0.5,ev->getNbrSamples()-0.5);

		//labeling the axis//
		TString XAxisTitle(Form("t [%0.1f ns]",ev->getSampleInterval()*1.e9));
		hists[chan]->SetXTitle(XAxisTitle.Data());
		hists[chan]->GetXaxis()->CenterTitle();
		hists[chan]->SetYTitle("U [mV]");
		hists[chan]->GetYaxis()->CenterTitle();
		hists[chan]->SetBit(TH1::kNoStats);
		//do not attach the hists to the file//
		hists[chan]->SetDirectory(0);
	
		//draw it to the right Pad
		c->cd(chan+1);
		hists[chan]->Draw("p0c");
	}
	//don't mark any of the subpads
	c->cd(0);
	picidx=0;
}



//___________________________________________________________________________________________________________________________________________________________
void MyEventViewer::view(MyEvent* ev)
{
	//go through all channels//
	for (int chan=0;chan < nbrOfHitsCreated;++chan)
	{
		//get Channel
		MyChannel *Chan = ev->getChannel(chan);

		//set the Y axis range//
		hists[chan]->SetAxisRange(-0.5*Chan->getFullScale(),0.5*Chan->getFullScale(),"Y");

		//first write the baseline to the histogram 
		for (int i=0;i<ev->getNbrSamples();++i)
			hists[chan]->SetBinContent(i+1,Chan->getOffset());

		//go through all found Pulses of this channel//
		for (int puls=0; puls < Chan->getNbrPulses(); ++puls)
		{
			//get Puls and data pointer from it//
			MyPuls *Puls = Chan->getPuls(puls);
			long *data = (long*) Puls->getData();		//we know that it is a int array general case this class is a template
			
			//add Data to Histogram//
			for (int i=0; i<Puls->getLength();++i)
				hists[chan]->SetBinContent(i+1+Puls->getIndexToFirstPoint(),data[i]*Chan->getVertGain());
		}
		//tell that the pad that keeps the histo has been modified
		c->GetPad(chan+1)->Modified();
	}
	//update//
	c->Update();
	c->Print(Form("%s_%d.gif",name.Data(),picidx++));
}



TCanvas* Canv(int hor, int ver)
{
	//find out which size is the max, so that all subpads are still rectangluar but not bigger than 367//
	double h = gClient->GetDisplayHeight();
	double w = gClient->GetDisplayWidth();
	h -=26;
	w -=10;
	double hm = h/(double)ver;
	double wm = w/(double)hor;
	double maxsize = (wm>hm)? hm:wm;
	if (maxsize > 500) maxsize = 500;
	double cw = gStyle->GetScreenFactor();	//root multiplies the height and the width by this number
											//so in order to get the wanted size we need to divide the values by this number first

	static int nbrCanv;
	char name[64];
	char title[64];
	sprintf(name,"MyC%i",nbrCanv);
	sprintf(title,"MyCanvas %i",nbrCanv);
	nbrCanv++;
	TCanvas * MyC = new TCanvas(name,title,-1,1,(int)(maxsize*(double)hor/cw),(int)(maxsize*(double)ver/cw));
	MyC->Divide(hor,ver,(float)0.0001,(float)0.0001);
	MyC->ToggleEventStatus();
	for (int i=1;i<=hor*ver;++i)
	{
		MyC->cd(i);
		gPad->SetRightMargin((float)0.15);
		gPad->SetLeftMargin((float)0.15);
		gPad->SetTopMargin((float)0.15);
		gPad->SetBottomMargin((float)0.15);
	}
	return MyC;
}

